package id.bureau.flutter_plugin_dfs_android

import android.content.Context
import android.util.Log
import androidx.annotation.NonNull
import com.prism.device.BureauInstanceProvider
import com.prism.device.models.ErrorResponse
import com.prism.device.models.SubmitResponse
import com.prism.device.tools.DataCallback
import com.prism.device.tools.ENV_SANDBOX

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** FlutterPluginDfsAndroidPlugin */
class FlutterPluginDfsAndroidPlugin : FlutterPlugin, MethodCallHandler {
    private lateinit var channel: MethodChannel
    private lateinit var context: Context

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        context = flutterPluginBinding.applicationContext
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "flutter_plugin_dfs_android")
        channel.setMethodCallHandler(this)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        if (call.method == "submitData") {
            val clientId = call.argument<String>("clientId")
            val sessionId = call.argument<String>("sessionId")
            val userId = call.argument<String>("userId") ?: ""
            val flow = call.argument<String>("flow") ?: ""
            Log.d("flutterPlugin", "initializing device fingerprint sdk in native")
            if (clientId != null && sessionId != null) {
                processBureauTest(clientId, sessionId, userId, flow)
            }
        } else {
            result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    private fun processBureauTest(
        clientId: String,
        sessionId: String,
        userId: String = "",
        flow: String = ""
    ) {
        val bureauAPI = BureauInstanceProvider.getBureauApiInstance(
            context, clientId,
            ENV_SANDBOX
        )

        bureauAPI.setSessionId(sessionId)
        bureauAPI.setUserId(userId)
        bureauAPI.setFlow(flow)

        bureauAPI.submit(object :
            DataCallback {
            override fun onError(errorMessage: ErrorResponse) {
                Log.w("TREE", "ERROR")
            }

            override fun onResult(message: SubmitResponse) {
                Log.w("TREE", "SUCCESS")
            }
        })
    }
}
